"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.onPreInit = void 0;
var options_1 = require("./options");
var fs_1 = __importDefault(require("fs"));
var path_1 = __importDefault(require("path"));
var utils_1 = require("./utils");
exports.onPreInit = function (_a, options) {
    var reporter = _a.reporter;
    checkConfig(reporter, options);
    if (((process.env.NODE_ENV === 'development' && !options.disableDevelopment) ||
        process.env.NODE_ENV === 'production') &&
        !options.removeFirebaseServiceWorker) {
        var firebaseSwText = replaceFirebasePlaceholders(reporter, options);
        if (!fs_1.default.existsSync('public')) {
            fs_1.default.mkdirSync('public');
        }
        fs_1.default.writeFile('public/firebase-messaging-sw.js', firebaseSwText, function (err) {
            err && console.log(err);
        });
    }
    else {
        deleteFirebaseSwFile();
    }
};
var replaceFirebasePlaceholders = function (reporter, options) {
    var _a;
    var placeholderStringArray = options_1.requiredConfigCredentials.map(function (credential) { return "%" + credential + "%"; });
    placeholderStringArray.push('%version%');
    var fbVersion = (_a = options.firebaseVersion) !== null && _a !== void 0 ? _a : utils_1.getFirebaseVersion(reporter);
    var re = new RegExp(placeholderStringArray.join('|'), 'g');
    var firebaseSwText = fs_1.default
        .readFileSync(path_1.default.join(__dirname, 'firebase-messaging-sw.js'))
        .toString()
        .replace(re, function (matched) { var _a, _b; return (_b = (_a = options.config) === null || _a === void 0 ? void 0 : _a[matched.replace(/%/g, '')]) !== null && _b !== void 0 ? _b : fbVersion; })
        .replace('"use strict";', '');
    return firebaseSwText;
};
var deleteFirebaseSwFile = function () {
    if (fs_1.default.existsSync('public/firebase-messaging-sw.js')) {
        fs_1.default.unlink('public/firebase-messaging-sw.js', function (err) {
            err && console.log(err);
        });
    }
};
var checkConfig = function (reporter, options) {
    if (!options.removeFirebaseServiceWorker) {
        if (!options.config) {
            reporter.warn("no 'config' option passed to gatsby-plugin-firebase-messaging");
        }
        var missingCredentials_1 = [];
        options_1.requiredConfigCredentials.forEach(function (credential) {
            if (!Object.keys(options.config).includes(credential)) {
                missingCredentials_1.push(credential);
            }
        });
        if (missingCredentials_1.length > 0) {
            reporter.warn("gatsby-plugin-firebase-messaging was missing the following required values:\n\n" + missingCredentials_1.join('\n'));
        }
    }
};
